Official Clojure SDK for atradio.fm.
JVM Panama (java.lang.foreign) bindings to the shared Rust core's C ABI (crates/atradio-uniffi). The auth / record / reconcile logic is identical to the Rust, Go, TypeScript, Python, and Ruby SDKs. Requires JDK 22+.
Official Clojure SDK for atradio.fm. JVM Panama (java.lang.foreign) bindings to the shared Rust core's C ABI (crates/atradio-uniffi). The auth / record / reconcile logic is identical to the Rust, Go, TypeScript, Python, and Ruby SDKs. Requires JDK 22+.
(agent-close agent)Release an agent's native handle.
Release an agent's native handle.
(favorite-rkey station-id)The deterministic favorite record key — identical across every atradio SDK.
The deterministic favorite record key — identical across every atradio SDK.
(favorites actor limit)(favorites actor limit base)An actor's favorited stations.
An actor's favorited stations.
(login session-path identifier password & {:keys [appview]})Log in with an app password, persisting the session at session-path.
Log in with an app password, persisting the session at `session-path`.
(recent-stations limit)(recent-stations limit base)Newest stations platform-wide.
Newest stations platform-wide.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |