Resolves the native atradio-uniffi library, downloading a prebuilt from the GitHub release on first use when it isn't already present locally.
Order of preference:
The jar ships resources/atradio/manifest.json (repo, release tag, one sha256 per target triple) — filled from the release artifacts by sdk/scripts/gen-uniffi-manifest.sh.
Resolves the native atradio-uniffi library, downloading a prebuilt from the
GitHub release on first use when it isn't already present locally.
Order of preference:
1. libatradio_uniffi.<ext> on the classpath (native/) — a local ./build.sh
dev build.
2. A checksum-verified copy in the user cache, downloaded on first load (the
published-jar path: the ~11 MB lib is not bundled in the jar).
The jar ships resources/atradio/manifest.json (repo, release tag, one sha256
per target triple) — filled from the release artifacts by
sdk/scripts/gen-uniffi-manifest.sh.(resolve-lib)Absolute path to a loadable native library, fetching it if necessary.
Absolute path to a loadable native library, fetching it if necessary.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |